summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyaccountselector.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneyaccountselector.h')
-rw-r--r--kmymoney2/widgets/kmymoneyaccountselector.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmymoney2/widgets/kmymoneyaccountselector.h b/kmymoney2/widgets/kmymoneyaccountselector.h
index dc03ceb..3c15023 100644
--- a/kmymoney2/widgets/kmymoneyaccountselector.h
+++ b/kmymoney2/widgets/kmymoneyaccountselector.h
@@ -60,7 +60,7 @@ class kMyMoneyAccountSelector : public KMyMoneySelector
public:
friend class AccountSet;
- kMyMoneyAccountSelector(TQWidget *tqparent=0, const char *name=0, TQWidget::WFlags flags = 0, const bool createButtons = true);
+ kMyMoneyAccountSelector(TQWidget *parent=0, const char *name=0, TQWidget::WFlags flags = 0, const bool createButtons = true);
virtual ~kMyMoneyAccountSelector();
/**
@@ -120,13 +120,13 @@ public slots:
protected:
/**
* This method loads the list of subaccounts as found in the
* @p list and attaches them to the tqparent widget passed as @p tqparent.
*
* @param tqparent pointer to tqparent widget
* @param list TQStringList containing the ids of all subaccounts to load
* @return This method returns the number of accounts loaded into the list
*/
- int loadSubAccounts(TQListViewItem* tqparent, const TQStringList& list);
+ int loadSubAccounts(TQListViewItem* parent, const TQStringList& list);
/**
* This is a helper method for selectAllIncomeCategories()
@@ -175,7 +175,7 @@ public:
bool isHidingClosedAccounts (void) { return m_hideClosedAccounts; }
protected:
- int loadSubAccounts(kMyMoneyAccountSelector* selector, TQListViewItem* tqparent, const TQString& key, const TQStringList& list);
+ int loadSubAccounts(kMyMoneyAccountSelector* selector, TQListViewItem* parent, const TQString& key, const TQStringList& list);
bool includeAccount(const MyMoneyAccount& acc);
private:
@@ -120,13 +120,13 @@ public slots:
/**
* This method loads the list of subaccounts as found in the
- * @p list and attaches them to the tqparent widget passed as @p tqparent.
+ * @p list and attaches them to the parent widget passed as @p parent.
*
@@ -120,13 +120,13 @@ public slots:
*
- * @param tqparent pointer to tqparent widget
+ * @param parent pointer to parent widget
* @param list TQStringList containing the ids of all subaccounts to load
* @return This method returns the number of accounts loaded into the list